"""Rules used by the `pydantic_marc` package to validate a MARC record.

This module contains a dictionary with rules that define attributes of a valid
MARC record based off of the rules file (marcrules.txt) used to validate MARC
records in MarcEdit (version 7.7). Recent changes to the MARC21 Format for
Bibliographic Data may not be reflected in these rules.

The `MARC_RULES` dictionary contains key, value pairs with a MARC tag and it's
associated rules. The rules defined for each field include:
    repeatable:
        Whether or not the tag can be repeated within a record.
    ind1:
        A list of valid values for a field's first indicator or None if the field
        should not contain indicators.
    ind2:
        A list of valid values for a field's second indicator or None if the field
        should not contain indicators.
    subfields:
        A dictionary containing lists of valid fields, repeatable fields, and
        non-repeatable fields.
    length:
        The expected length of the data attribute of a control field. represented
        as an integer if there is only one valid length or a dictionary if the
        length of the field is dependent on the material type.

"""

from typing import Any, Dict

MARC_RULES: Dict[str, Any] = {
    "001": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "003": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "005": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "006": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": 18,
        "required": False,
    },
    "007": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": {
            "a": 8,
            "c": [6, 14],
            "d": 6,
            "f": 10,
            "g": 9,
            "h": 13,
            "k": 6,
            "m": 23,
            "o": 2,
            "q": 2,
            "r": 11,
            "s": 14,
            "t": 2,
            "v": 9,
            "z": 2,
        },
        "required": False,
    },
    "008": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": 40,
        "required": True,
    },
    "010": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "z", "8"],
            "repeatable": ["b", "z", "8"],
            "non_repeatable": ["a"],
        },
        "length": None,
        "required": False,
    },
    "013": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "6", "8"],
            "repeatable": ["d", "e", "f", "8"],
            "non_repeatable": ["a", "b", "c", "6"],
        },
        "length": None,
        "required": False,
    },
    "015": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "2", "6", "8"],
            "repeatable": ["a", "z", "8"],
            "non_repeatable": ["2", "6"],
        },
        "length": None,
        "required": False,
    },
    "016": {
        "repeatable": True,
        "ind1": ["", " ", "7"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "2", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "2"],
        },
        "length": None,
        "required": False,
    },
    "017": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": ["a", "b", "d", "i", "z", "2", "6", "8"],
            "repeatable": ["a", "z", "8"],
            "non_repeatable": ["b", "d", "i", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "018": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "020": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "c", "q", "z", "6", "8"],
            "repeatable": ["q", "z", "8"],
            "non_repeatable": ["a", "c", "6"],
        },
        "length": None,
        "required": False,
    },
    "022": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "l", "m", "y", "z", "2", "6", "8"],
            "repeatable": ["m", "y", "z", "8"],
            "non_repeatable": ["a", "l", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "024": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "7", "8"],
        "ind2": ["", " ", "0", "1"],
        "subfields": {
            "valid": ["a", "c", "d", "z", "2", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "c", "d", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "025": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": [],
        },
        "length": None,
        "required": False,
    },
    "026": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "2", "5", "6", "8"],
            "repeatable": ["a", "b", "d", "5", "8"],
            "non_repeatable": ["c", "e", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "027": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "028": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "5", "6"],
        "ind2": ["0", "1", "2", "3"],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "030": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "031": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "g",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "y",
                "z",
                "2",
                "6",
                "8",
            ],
            "repeatable": ["d", "q", "s", "t", "u", "y", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "e",
                "g",
                "m",
                "n",
                "o",
                "p",
                "r",
                "2",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "032": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "033": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2"],
        "ind2": ["", " ", "0", "1", "2"],
        "subfields": {
            "valid": ["a", "b", "c", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "c", "0", "1", "2", "8"],
            "non_repeatable": ["3", "6"],
        },
        "length": None,
        "required": False,
    },
    "034": {
        "repeatable": True,
        "ind1": ["0", "1", "3"],
        "ind2": ["", " ", "0", "1"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "m",
                "n",
                "p",
                "s",
                "t",
                "x",
                "y",
                "z",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["b", "c", "h", "s", "t", "1", "8"],
            "non_repeatable": [
                "a",
                "d",
                "e",
                "f",
                "g",
                "j",
                "k",
                "m",
                "n",
                "p",
                "x",
                "y",
                "z",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "035": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "z", "6", "8"],
            "repeatable": ["b", "z", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "036": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "037": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "f", "g", "n", "6", "8"],
            "repeatable": ["c", "f", "g", "n", "8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "038": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "040": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "6", "8"],
            "repeatable": ["d", "e", "8"],
            "non_repeatable": ["a", "b", "c", "6"],
        },
        "length": None,
        "required": False,
    },
    "041": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " ", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "n",
                "p",
                "q",
                "r",
                "t",
                "2",
                "6",
                "8",
            ],
            "repeatable": [
                "a",
                "b",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "n",
                "p",
                "q",
                "r",
                "t",
                "8",
            ],
            "non_repeatable": ["2", "6"],
        },
        "length": None,
        "required": False,
    },
    "042": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {"valid": ["a"], "repeatable": ["a"], "non_repeatable": []},
        "length": None,
        "required": False,
    },
    "043": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "0", "1", "2", "6", "8"],
            "repeatable": ["a", "b", "c", "0", "1", "2", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "044": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "2", "6", "8"],
            "repeatable": ["a", "b", "c", "2", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "045": {
        "repeatable": False,
        "ind1": ["", " ", "0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "6", "8"],
            "repeatable": ["a", "b", "c", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "046": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "j", "k", "l", "m", "n", "2", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "j",
                "k",
                "l",
                "m",
                "n",
                "2",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "047": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " ", "7"],
        "subfields": {
            "valid": ["a", "2", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["2"],
        },
        "length": None,
        "required": False,
    },
    "048": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " ", "7"],
        "subfields": {
            "valid": ["a", "b", "2", "8"],
            "repeatable": ["a", "b", "8"],
            "non_repeatable": ["2"],
        },
        "length": None,
        "required": False,
    },
    "050": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["0", "4"],
        "subfields": {
            "valid": ["a", "b", "0", "1", "3", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["b", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "051": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "c"],
        },
        "length": None,
        "required": False,
    },
    "052": {
        "repeatable": True,
        "ind1": ["", " ", "1", "7"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "d", "0", "1", "2", "6", "8"],
            "repeatable": ["b", "d", "0", "1", "8"],
            "non_repeatable": ["a", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "055": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "8"],
            "repeatable": ["0", "1", "8"],
            "non_repeatable": ["a", "b", "2"],
        },
        "length": None,
        "required": False,
    },
    "060": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["0", "4"],
        "subfields": {
            "valid": ["a", "b", "0", "1", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["b"],
        },
        "length": None,
        "required": False,
    },
    "061": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["b", "c"],
        },
        "length": None,
        "required": False,
    },
    "066": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c"],
            "repeatable": ["c"],
            "non_repeatable": ["a", "b"],
        },
        "length": None,
        "required": False,
    },
    "070": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["b"],
        },
        "length": None,
        "required": False,
    },
    "071": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["b", "c"],
        },
        "length": None,
        "required": False,
    },
    "072": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "7"],
        "subfields": {
            "valid": ["a", "x", "2", "6", "8"],
            "repeatable": ["x", "8"],
            "non_repeatable": ["a", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "074": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a"],
        },
        "length": None,
        "required": False,
    },
    "080": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "x", "0", "1", "2", "6", "8"],
            "repeatable": ["x", "0", "1", "8"],
            "non_repeatable": ["a", "b", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "082": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "0", "4"],
        "subfields": {
            "valid": ["a", "b", "m", "q", "2", "6", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["b", "m", "q", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "083": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "c", "m", "q", "y", "z", "2", "6", "8"],
            "repeatable": ["a", "c", "y", "z", "8"],
            "non_repeatable": ["m", "q", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "084": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["b", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "085": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "f",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "y",
                "z",
                "0",
                "1",
                "6",
                "8",
            ],
            "repeatable": [
                "a",
                "b",
                "c",
                "f",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "y",
                "z",
                "0",
                "1",
                "8",
            ],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "086": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "0", "1", "2", "6", "8"],
            "repeatable": ["z", "0", "1", "8"],
            "non_repeatable": ["a", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "088": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "100": {
        "repeatable": False,
        "ind1": ["0", "1", "3"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "j",
                "k",
                "l",
                "n",
                "p",
                "q",
                "t",
                "u",
                "0",
                "1",
                "2",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["c", "e", "j", "k", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": ["a", "b", "d", "f", "g", "l", "q", "t", "u", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "110": {
        "repeatable": False,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "k",
                "l",
                "n",
                "p",
                "t",
                "u",
                "0",
                "1",
                "2",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["b", "d", "e", "k", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": ["a", "c", "f", "g", "l", "t", "u", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "111": {
        "repeatable": False,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "e",
                "f",
                "g",
                "j",
                "k",
                "l",
                "n",
                "p",
                "q",
                "t",
                "u",
                "0",
                "1",
                "2",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["e", "j", "k", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": ["a", "c", "d", "f", "g", "l", "q", "t", "u", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "130": {
        "repeatable": False,
        "ind1": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "d",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "0",
                "1",
                "2",
                "6",
                "8",
            ],
            "repeatable": ["d", "k", "m", "n", "p", "0", "1", "8"],
            "non_repeatable": ["a", "f", "g", "h", "l", "o", "r", "s", "t", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "210": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "0"],
        "subfields": {
            "valid": ["a", "b", "2", "6", "8"],
            "repeatable": ["2", "8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "222": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "240": {
        "repeatable": False,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": [
                "a",
                "d",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "0",
                "1",
                "2",
                "6",
                "8",
            ],
            "repeatable": ["d", "k", "m", "n", "p", "0", "1", "8"],
            "non_repeatable": ["a", "f", "g", "h", "l", "o", "r", "s", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "242": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": ["a", "b", "c", "h", "n", "p", "y", "6", "8"],
            "repeatable": ["n", "p", "8"],
            "non_repeatable": ["a", "b", "c", "h", "y", "6"],
        },
        "length": None,
        "required": False,
    },
    "243": {
        "repeatable": False,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": [
                "a",
                "d",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "6",
                "8",
            ],
            "repeatable": ["d", "k", "m", "n", "p", "8"],
            "non_repeatable": ["a", "f", "g", "h", "l", "o", "r", "s", "6"],
        },
        "length": None,
        "required": False,
    },
    "245": {
        "repeatable": False,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": ["a", "b", "c", "f", "g", "h", "k", "n", "p", "s", "6", "8"],
            "repeatable": ["k", "n", "p", "8"],
            "non_repeatable": ["a", "b", "c", "f", "g", "h", "s", "6"],
        },
        "length": None,
        "required": True,
    },
    "246": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3"],
        "ind2": ["", " ", "0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "subfields": {
            "valid": ["a", "b", "f", "g", "h", "i", "n", "p", "5", "6", "8"],
            "repeatable": ["n", "p", "8"],
            "non_repeatable": ["a", "b", "f", "g", "h", "i", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "247": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["0", "1"],
        "subfields": {
            "valid": ["a", "b", "f", "g", "h", "n", "p", "x", "6", "8"],
            "repeatable": ["n", "p", "8"],
            "non_repeatable": ["a", "b", "f", "g", "h", "x", "6"],
        },
        "length": None,
        "required": False,
    },
    "250": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "251": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "254": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "255": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "c", "d", "e", "f", "g", "6"],
        },
        "length": None,
        "required": False,
    },
    "256": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "257": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["2", "6"],
        },
        "length": None,
        "required": False,
    },
    "258": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "260": {
        "repeatable": True,
        "ind1": ["", " ", "2", "3"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "3", "6", "8"],
            "repeatable": ["a", "b", "c", "e", "f", "g", "8"],
            "non_repeatable": ["d", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "261": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "d", "e", "f", "6", "8"],
            "repeatable": ["a", "b", "d", "e", "f", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "262": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "k", "l", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "c", "k", "l", "6"],
        },
        "length": None,
        "required": False,
    },
    "263": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "264": {
        "repeatable": True,
        "ind1": ["", " ", "2", "3"],
        "ind2": ["0", "1", "2", "3", "4"],
        "subfields": {
            "valid": ["a", "b", "c", "3", "6", "8"],
            "repeatable": ["a", "b", "c", "8"],
            "non_repeatable": ["3", "6"],
        },
        "length": None,
        "required": False,
    },
    "270": {
        "repeatable": True,
        "ind1": ["", " ", "1", "2"],
        "ind2": ["", " ", "0", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "p",
                "q",
                "r",
                "z",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["a", "j", "k", "l", "m", "n", "p", "q", "r", "z", "4", "8"],
            "non_repeatable": ["b", "c", "d", "e", "f", "g", "h", "i", "6"],
        },
        "length": None,
        "required": False,
    },
    "300": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "e", "f", "g", "3", "6", "8"],
            "repeatable": ["a", "c", "f", "g", "8"],
            "non_repeatable": ["b", "e", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "306": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "307": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "310": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "321": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "336": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "337": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "338": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "340": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "n",
                "o",
                "0",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "n",
                "o",
                "0",
                "1",
                "8",
            ],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "342": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "2",
                "6",
                "8",
            ],
            "repeatable": ["e", "f", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "2",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "343": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "h", "i", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "c", "d", "e", "f", "g", "h", "i", "6"],
        },
        "length": None,
        "required": False,
    },
    "344": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "0",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["a", "b", "c", "d", "e", "f", "g", "h", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "345": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "346": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "347": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "c", "d", "e", "f", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "348": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "351": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "3", "6", "8"],
            "repeatable": ["a", "b", "8"],
            "non_repeatable": ["c", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "352": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "i", "q", "6", "8"],
            "repeatable": ["b", "c", "q", "8"],
            "non_repeatable": ["a", "d", "e", "f", "g", "i", "6"],
        },
        "length": None,
        "required": False,
    },
    "355": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "5", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "h", "j", "6", "8"],
            "repeatable": ["b", "c", "j", "8"],
            "non_repeatable": ["a", "d", "e", "f", "g", "h", "6"],
        },
        "length": None,
        "required": False,
    },
    "357": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "g", "6", "8"],
            "repeatable": ["b", "c", "g", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "362": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "z", "6"],
        },
        "length": None,
        "required": False,
    },
    "363": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " ", "0", "1"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "u",
                "v",
                "x",
                "z",
                "6",
                "8",
            ],
            "repeatable": ["x", "z"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "u",
                "v",
                "6",
                "8",
            ],
        },
        "length": None,
        "required": False,
    },
    "365": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "2",
                "6",
                "8",
            ],
            "repeatable": ["8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "2",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "366": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "j", "k", "m", "2", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "j",
                "k",
                "m",
                "2",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "370": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["c", "f", "g", "s", "t", "u", "v", "0", "1", "2", "6", "8"],
            "repeatable": ["c", "f", "g", "u", "v", "0", "1", "8"],
            "non_repeatable": ["s", "t", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "377": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " ", "7"],
        "subfields": {
            "valid": ["a", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "380": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "381": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "u", "v", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "u", "v", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "382": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " ", "0", "1"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "d",
                "e",
                "n",
                "p",
                "r",
                "s",
                "t",
                "v",
                "0",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["a", "b", "d", "e", "n", "p", "v", "0", "1", "8"],
            "non_repeatable": ["r", "s", "t", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "383": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "2", "6", "8"],
            "repeatable": ["a", "b", "c"],
            "non_repeatable": ["d", "e", "2", "6", "8"],
        },
        "length": None,
        "required": False,
    },
    "384": {
        "repeatable": False,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "385": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "m", "n", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "8"],
            "non_repeatable": ["m", "n", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "386": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "m", "n", "0", "1", "2", "3", "4", "6", "8"],
            "repeatable": ["a", "b", "0", "1", "4", "8"],
            "non_repeatable": ["m", "n", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "388": {
        "repeatable": True,
        "ind1": ["", " ", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["a", "0", "1", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "400": {
        "repeatable": True,
        "ind1": ["0", "1", "3"],
        "ind2": ["0", "1"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "k",
                "l",
                "n",
                "p",
                "t",
                "u",
                "v",
                "x",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["c", "e", "k", "n", "p", "4", "8"],
            "non_repeatable": ["a", "b", "d", "f", "g", "l", "t", "u", "v", "x", "6"],
        },
        "length": None,
        "required": False,
    },
    "410": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["0", "1"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "k",
                "l",
                "n",
                "p",
                "t",
                "u",
                "v",
                "x",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["b", "d", "e", "k", "n", "p", "4", "8"],
            "non_repeatable": ["a", "c", "f", "g", "l", "t", "u", "v", "x", "6"],
        },
        "length": None,
        "required": False,
    },
    "411": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["0", "1"],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "e",
                "f",
                "g",
                "k",
                "l",
                "n",
                "p",
                "q",
                "t",
                "u",
                "v",
                "x",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["e", "k", "n", "p", "4", "8"],
            "non_repeatable": [
                "a",
                "c",
                "d",
                "f",
                "g",
                "l",
                "q",
                "t",
                "u",
                "v",
                "x",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "440": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": ["a", "n", "p", "v", "x", "w", "0", "6", "8"],
            "repeatable": ["n", "p", "w", "0", "8"],
            "non_repeatable": ["a", "v", "x", "6"],
        },
        "length": None,
        "required": False,
    },
    "490": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "l", "v", "x", "3", "6", "8"],
            "repeatable": ["a", "v", "8"],
            "non_repeatable": ["l", "x", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "500": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "3", "5", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "501": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "5", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "502": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "g", "o", "6", "8"],
            "repeatable": ["g", "o", "8"],
            "non_repeatable": ["a", "b", "c", "d", "6"],
        },
        "length": None,
        "required": False,
    },
    "504": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "505": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "8"],
        "ind2": ["", " ", "0"],
        "subfields": {
            "valid": ["a", "g", "r", "t", "u", "6", "8"],
            "repeatable": ["g", "r", "t", "u", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "506": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "u", "2", "3", "5", "6", "8"],
            "repeatable": ["b", "c", "d", "e", "f", "u", "8"],
            "non_repeatable": ["a", "2", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "507": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "508": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "510": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "x", "3", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "c", "x", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "511": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "513": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "514": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "u",
                "z",
                "6",
                "8",
            ],
            "repeatable": ["b", "c", "g", "h", "j", "k", "u", "z", "8"],
            "non_repeatable": ["a", "d", "e", "f", "i", "m", "6"],
        },
        "length": None,
        "required": False,
    },
    "515": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "516": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "518": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["0", "1", "8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "520": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2", "3", "4", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "u", "2", "3", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "b", "c", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "521": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2", "3", "4", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "3", "6", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["b", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "522": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "524": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "2", "3", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "525": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "526": {
        "repeatable": True,
        "ind1": ["0", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "i", "x", "z", "5", "6", "8"],
            "repeatable": ["x", "z", "8"],
            "non_repeatable": ["a", "b", "c", "d", "i", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "530": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "u", "3", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "b", "c", "d", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "533": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "m", "n", "3", "5", "6", "7", "8"],
            "repeatable": ["b", "c", "f", "m", "n", "8"],
            "non_repeatable": ["a", "d", "e", "3", "5", "6", "7"],
        },
        "length": None,
        "required": False,
    },
    "534": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "e",
                "f",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "t",
                "x",
                "z",
                "6",
                "8",
            ],
            "repeatable": ["f", "k", "n", "o", "x", "z", "8"],
            "non_repeatable": ["a", "b", "c", "e", "l", "m", "p", "t", "6"],
        },
        "length": None,
        "required": False,
    },
    "535": {
        "repeatable": True,
        "ind1": ["1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "g", "3", "6", "8"],
            "repeatable": ["b", "c", "d", "8"],
            "non_repeatable": ["a", "g", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "536": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "h", "6", "8"],
            "repeatable": ["b", "c", "d", "e", "f", "g", "h", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "538": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "i", "u", "3", "5", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "i", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "540": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "u", "3", "5", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "b", "c", "d", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "541": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "h", "n", "o", "3", "5", "6", "8"],
            "repeatable": ["n", "o", "8"],
            "non_repeatable": ["a", "b", "c", "d", "e", "f", "h", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "542": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "q",
                "r",
                "s",
                "u",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["d", "e", "f", "h", "k", "n", "u", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "g",
                "i",
                "j",
                "l",
                "m",
                "o",
                "q",
                "r",
                "s",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "544": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "n", "3", "6", "8"],
            "repeatable": ["a", "b", "c", "d", "e", "n", "8"],
            "non_repeatable": ["3", "6"],
        },
        "length": None,
        "required": False,
    },
    "545": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "u", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "b", "6"],
        },
        "length": None,
        "required": False,
    },
    "546": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "3", "6", "8"],
            "repeatable": ["b", "8"],
            "non_repeatable": ["a", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "547": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "550": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "552": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "u",
                "z",
                "6",
                "8",
            ],
            "repeatable": ["e", "f", "o", "p", "u", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "555": {
        "repeatable": True,
        "ind1": ["", " ", "0", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "u", "3", "6", "8"],
            "repeatable": ["b", "u", "8"],
            "non_repeatable": ["a", "c", "d", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "556": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "561": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "3", "5", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "562": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "3", "5", "6", "8"],
            "repeatable": ["a", "b", "c", "d", "e", "8"],
            "non_repeatable": ["3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "563": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "u", "3", "5", "6", "8"],
            "repeatable": ["u", "8"],
            "non_repeatable": ["a", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "565": {
        "repeatable": True,
        "ind1": ["", " ", "0", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "3", "6", "8"],
            "repeatable": ["b", "c", "d", "e", "8"],
            "non_repeatable": ["a", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "567": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "0", "1", "2", "6", "8"],
            "repeatable": ["0", "1", "8"],
            "non_repeatable": ["a", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "580": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "581": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "z", "3", "6", "8"],
            "repeatable": ["z", "8"],
            "non_repeatable": ["a", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "583": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "h",
                "i",
                "j",
                "k",
                "l",
                "n",
                "o",
                "u",
                "x",
                "z",
                "2",
                "3",
                "5",
                "6",
                "8",
            ],
            "repeatable": [
                "b",
                "c",
                "d",
                "e",
                "f",
                "h",
                "i",
                "j",
                "k",
                "l",
                "n",
                "o",
                "u",
                "x",
                "z",
                "8",
            ],
            "non_repeatable": ["a", "2", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "584": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "3", "5", "6", "8"],
            "repeatable": ["a", "b", "8"],
            "non_repeatable": ["3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "585": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "3", "5", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "586": {
        "repeatable": True,
        "ind1": ["", " ", "8"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "3", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "588": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "5", "6", "8"],
            "repeatable": ["8"],
            "non_repeatable": ["a", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "600": {
        "repeatable": True,
        "ind1": ["0", "1", "3"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": [
                "c",
                "e",
                "j",
                "k",
                "m",
                "n",
                "p",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "4",
                "8",
            ],
            "non_repeatable": [
                "a",
                "b",
                "d",
                "f",
                "g",
                "h",
                "l",
                "o",
                "q",
                "r",
                "s",
                "t",
                "u",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "610": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "u",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": [
                "b",
                "d",
                "e",
                "k",
                "m",
                "n",
                "p",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "4",
                "8",
            ],
            "non_repeatable": [
                "a",
                "c",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "u",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "611": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "n",
                "p",
                "q",
                "s",
                "t",
                "u",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": [
                "e",
                "j",
                "k",
                "n",
                "p",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "4",
                "8",
            ],
            "non_repeatable": [
                "a",
                "c",
                "d",
                "f",
                "g",
                "h",
                "l",
                "q",
                "s",
                "t",
                "u",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "630": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "d",
                "e",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": [
                "d",
                "e",
                "k",
                "m",
                "n",
                "p",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "4",
                "8",
            ],
            "non_repeatable": [
                "a",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "647": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "g",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["c", "g", "v", "x", "y", "z", "0", "1", "8"],
            "non_repeatable": ["a", "d", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "648": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": ["a", "v", "x", "y", "z", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["v", "x", "y", "z", "0", "1", "8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "650": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["v", "x", "y", "z", "0", "1", "4", "8"],
            "non_repeatable": ["a", "b", "c", "d", "e", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "651": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": ["a", "e", "v", "x", "y", "z", "0", "1", "2", "3", "4", "6", "8"],
            "repeatable": ["e", "v", "x", "y", "z", "0", "1", "4", "8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "653": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2"],
        "ind2": ["", " ", "0", "1", "2", "3", "4", "5", "6"],
        "subfields": {
            "valid": ["a", "6", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "654": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "e",
                "v",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["a", "b", "c", "e", "v", "y", "z", "0", "1", "4", "8"],
            "non_repeatable": ["2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "655": {
        "repeatable": True,
        "ind1": ["", " ", "0"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "v",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "5",
                "6",
                "8",
            ],
            "repeatable": ["b", "c", "v", "x", "y", "z", "0", "1", "8"],
            "non_repeatable": ["a", "2", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "656": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["7"],
        "subfields": {
            "valid": ["a", "k", "v", "x", "y", "z", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["v", "x", "y", "z", "0", "1", "8"],
            "non_repeatable": ["a", "k", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "657": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["7"],
        "subfields": {
            "valid": ["a", "v", "x", "y", "z", "0", "1", "2", "3", "6", "8"],
            "repeatable": ["v", "x", "y", "z", "0", "1", "8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "658": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "2", "6", "8"],
            "repeatable": ["b", "8"],
            "non_repeatable": ["a", "c", "d", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "662": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "0",
                "1",
                "2",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["a", "c", "e", "f", "g", "h", "0", "1", "4", "8"],
            "non_repeatable": ["b", "d", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "700": {
        "repeatable": True,
        "ind1": ["0", "1", "3"],
        "ind2": ["", " ", "2"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "8",
            ],
            "repeatable": ["c", "e", "j", "k", "m", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "b",
                "d",
                "f",
                "g",
                "h",
                "l",
                "o",
                "q",
                "r",
                "s",
                "t",
                "u",
                "x",
                "2",
                "3",
                "5",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "710": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " ", "2"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "u",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "8",
            ],
            "repeatable": ["b", "d", "e", "k", "m", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "c",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "u",
                "x",
                "2",
                "3",
                "5",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "711": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " ", "2"],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "n",
                "p",
                "q",
                "s",
                "t",
                "u",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "8",
            ],
            "repeatable": ["e", "j", "k", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "c",
                "d",
                "f",
                "g",
                "h",
                "l",
                "q",
                "s",
                "t",
                "u",
                "x",
                "2",
                "3",
                "5",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "720": {
        "repeatable": True,
        "ind1": ["", " ", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "e", "4", "6", "8"],
            "repeatable": ["e", "4", "8"],
            "non_repeatable": ["a", "6"],
        },
        "length": None,
        "required": False,
    },
    "730": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "ind2": ["", " ", "2"],
        "subfields": {
            "valid": [
                "a",
                "d",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "8",
            ],
            "repeatable": ["d", "k", "m", "n", "p", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "x",
                "2",
                "3",
                "5",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "740": {
        "repeatable": True,
        "ind1": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "ind2": ["", " ", "2"],
        "subfields": {
            "valid": ["a", "h", "n", "p", "5", "6", "8"],
            "repeatable": ["n", "p", "8"],
            "non_repeatable": ["a", "h", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "751": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "e", "0", "1", "2", "3", "4", "6", "8"],
            "repeatable": ["e", "0", "1", "4", "8"],
            "non_repeatable": ["a", "2", "3", "6"],
        },
        "length": None,
        "required": False,
    },
    "752": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "e", "f", "g", "h", "0", "1", "2", "6", "8"],
            "repeatable": ["e", "f", "g", "h", "0", "1", "8"],
            "non_repeatable": ["a", "b", "c", "d", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "753": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "0", "1", "2", "6", "8"],
            "repeatable": ["0", "1", "8"],
            "non_repeatable": ["a", "b", "c", "2", "6"],
        },
        "length": None,
        "required": False,
    },
    "754": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "c", "d", "x", "z", "0", "1", "2", "6", "8"],
            "repeatable": ["a", "c", "d", "x", "z", "0", "1", "8"],
            "non_repeatable": ["2", "6"],
        },
        "length": None,
        "required": False,
    },
    "758": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "i", "0", "1", "2", "3", "4", "5", "6", "8"],
            "repeatable": ["i", "0", "1", "4", "8"],
            "non_repeatable": ["a", "2", "3", "5", "6"],
        },
        "length": None,
        "required": False,
    },
    "760": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "m",
                "n",
                "o",
                "s",
                "t",
                "w",
                "x",
                "y",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "n", "o", "w", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "762": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "m",
                "n",
                "o",
                "s",
                "t",
                "w",
                "x",
                "y",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "n", "o", "w", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "765": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "767": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "770": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "772": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "0", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "773": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "3",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "d",
                "h",
                "i",
                "m",
                "p",
                "q",
                "s",
                "t",
                "u",
                "x",
                "y",
                "3",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "774": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "775": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "776": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "777": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "s",
                "t",
                "w",
                "x",
                "y",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "w", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "780": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "785": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "786": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "j",
                "k",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "j",
                "m",
                "p",
                "s",
                "t",
                "u",
                "v",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "787": {
        "repeatable": True,
        "ind1": ["0", "1"],
        "ind2": ["", " ", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "g",
                "h",
                "i",
                "k",
                "m",
                "n",
                "o",
                "r",
                "s",
                "t",
                "u",
                "w",
                "x",
                "y",
                "z",
                "6",
                "7",
                "8",
            ],
            "repeatable": ["g", "k", "n", "o", "r", "w", "z", "8"],
            "non_repeatable": [
                "a",
                "b",
                "c",
                "d",
                "h",
                "i",
                "m",
                "s",
                "t",
                "u",
                "x",
                "y",
                "6",
                "7",
            ],
        },
        "length": None,
        "required": False,
    },
    "800": {
        "repeatable": True,
        "ind1": ["0", "1", "3"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["c", "e", "j", "k", "m", "n", "p", "w", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "b",
                "d",
                "f",
                "g",
                "h",
                "l",
                "o",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "x",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "810": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["b", "d", "e", "k", "m", "n", "p", "w", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "c",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "u",
                "v",
                "x",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "811": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "j",
                "k",
                "l",
                "n",
                "p",
                "q",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "0",
                "1",
                "2",
                "3",
                "4",
                "6",
                "8",
            ],
            "repeatable": ["e", "j", "k", "n", "p", "w", "0", "1", "4", "8"],
            "non_repeatable": [
                "a",
                "c",
                "d",
                "f",
                "g",
                "h",
                "l",
                "q",
                "s",
                "t",
                "u",
                "v",
                "x",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "830": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": [
                "a",
                "d",
                "f",
                "g",
                "h",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "r",
                "s",
                "t",
                "v",
                "w",
                "x",
                "0",
                "1",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": ["d", "k", "m", "n", "p", "w", "0", "1", "8"],
            "non_repeatable": [
                "a",
                "f",
                "g",
                "h",
                "l",
                "o",
                "r",
                "s",
                "t",
                "v",
                "x",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "841": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "842": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "843": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "844": {
        "repeatable": False,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "845": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "850": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "8"],
            "repeatable": ["a", "8"],
            "non_repeatable": [],
        },
        "length": None,
        "required": False,
    },
    "852": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "ind2": ["", " ", "0", "1", "2"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "p",
                "q",
                "s",
                "t",
                "u",
                "x",
                "z",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": [
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "i",
                "k",
                "m",
                "s",
                "u",
                "x",
                "z",
            ],
            "non_repeatable": [
                "a",
                "h",
                "j",
                "l",
                "n",
                "p",
                "q",
                "t",
                "2",
                "3",
                "6",
                "8",
            ],
        },
        "length": None,
        "required": False,
    },
    "853": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "854": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "855": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "856": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2", "3", "4", "7"],
        "ind2": ["", " ", "0", "1", "2", "8"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "f",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "2",
                "3",
                "6",
                "8",
            ],
            "repeatable": [
                "a",
                "b",
                "c",
                "d",
                "f",
                "i",
                "m",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "8",
            ],
            "non_repeatable": [
                "h",
                "j",
                "k",
                "l",
                "n",
                "o",
                "p",
                "q",
                "r",
                "2",
                "3",
                "6",
            ],
        },
        "length": None,
        "required": False,
    },
    "863": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "864": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "865": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "866": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "867": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "868": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "876": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "877": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "878": {
        "repeatable": True,
        "ind1": None,
        "ind2": None,
        "subfields": None,
        "length": None,
        "required": False,
    },
    "880": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "ind2": ["", " ", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "7",
                "8",
                "9",
            ],
            "repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "0",
                "1",
                "3",
                "4",
                "5",
                "6",
                "7",
                "8",
                "9",
            ],
            "non_repeatable": ["2"],
        },
        "length": None,
        "required": False,
    },
    "882": {
        "repeatable": False,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "i", "w", "6", "8"],
            "repeatable": ["a", "i", "w", "8"],
            "non_repeatable": ["6"],
        },
        "length": None,
        "required": False,
    },
    "883": {
        "repeatable": True,
        "ind1": ["", " ", "0", "1"],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "c", "d", "q", "x", "u", "w", "0", "1", "8"],
            "repeatable": ["w", "0", "1", "8"],
            "non_repeatable": ["a", "c", "d", "q", "x", "u"],
        },
        "length": None,
        "required": False,
    },
    "884": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "g", "k", "q", "u"],
            "repeatable": ["u"],
            "non_repeatable": ["a", "g", "k", "q"],
        },
        "length": None,
        "required": False,
    },
    "885": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "b", "c", "d", "w", "x", "z", "0", "1", "2", "5"],
            "repeatable": ["w", "x", "z", "0", "1"],
            "non_repeatable": ["a", "b", "c", "d", "2", "5"],
        },
        "length": None,
        "required": False,
    },
    "886": {
        "repeatable": True,
        "ind1": ["0", "1", "2"],
        "ind2": ["", " "],
        "subfields": {
            "valid": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "7",
                "8",
                "9",
            ],
            "repeatable": [
                "a",
                "b",
                "c",
                "d",
                "e",
                "f",
                "g",
                "h",
                "i",
                "j",
                "k",
                "l",
                "m",
                "n",
                "o",
                "p",
                "q",
                "r",
                "s",
                "t",
                "u",
                "v",
                "w",
                "x",
                "y",
                "z",
                "0",
                "1",
                "2",
                "3",
                "4",
                "5",
                "6",
                "7",
                "8",
                "9",
            ],
            "non_repeatable": [],
        },
        "length": None,
        "required": False,
    },
    "887": {
        "repeatable": True,
        "ind1": ["", " "],
        "ind2": ["", " "],
        "subfields": {
            "valid": ["a", "2"],
            "repeatable": [],
            "non_repeatable": ["a", "2"],
        },
        "length": None,
        "required": False,
    },
}
